@@ -1,6 +1,8 @@
 import sys
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'ABIFLAGS': '',
+build_time_vars = {'ABI3DLLLIBRARY': 'libpython3.dll',
+ 'ABI3LDLIBRARY': 'libpython3.dll.a',
+ 'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
@@ -45,7 +47,7 @@ build_time_vars = {'ABIFLAGS': '',
                             '-fvisibility=hidden -D_WIN32_WINNT=0x0602 '
                             '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                             '-DMS_DLL_ID=\'"3.11-32"\'',
- 'CONFIGURE_CPPFLAGS': '-I../Python-3.11.4/PC -D__USE_MINGW_ANSI_STDIO=1 -I.',
+ 'CONFIGURE_CPPFLAGS': '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I.',
  'CONFIGURE_LDFLAGS': '-pipe -Wl,--no-seh -Wl,--large-address-aware '
                       '-Wl,--large-address-aware',
  'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition',
@@ -73,15 +75,16 @@ build_time_vars = {'ABIFLAGS': '',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
- 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.4/Include '
-             '-I../Python-3.11.4/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+ 'CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.8/Include '
+             '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
              '-D__USE_MINGW_ANSI_STDIO=1',
  'CXX': 'g++',
  'DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
  'DECIMAL_LDFLAGS': '-lmpdec',
- 'DEEPFREEZE_DEPS': '../Python-3.11.4/Tools/scripts/deepfreeze.py '
+ 'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
+ 'DEEPFREEZE_DEPS': '../Python-3.11.8/Tools/scripts/deepfreeze.py '
                     '_bootstrap_python '
-                    '../Python-3.11.4/Programs/_freeze_module.py \\',
+                    '../Python-3.11.8/Programs/_freeze_module.py \\',
  'DEEPFREEZE_OBJS': 'Python/deepfreeze/deepfreeze.o',
  'DESTDIR': '',
  'DESTDIRFINAL': '/',
@@ -121,11 +124,11 @@ build_time_vars = {'ABIFLAGS': '',
  'FILEMODE': 644,
  'FLOAT_WORDS_BIGENDIAN': 0,
  'FREEZE_MODULE': './_bootstrap_python '
-                  '../Python-3.11.4/Programs/_freeze_module.py',
+                  '../Python-3.11.8/Programs/_freeze_module.py',
  'FREEZE_MODULE_BOOTSTRAP': './Programs/_freeze_module',
  'FREEZE_MODULE_BOOTSTRAP_DEPS': 'Programs/_freeze_module',
  'FREEZE_MODULE_DEPS': '_bootstrap_python '
-                       '../Python-3.11.4/Programs/_freeze_module.py',
+                       '../Python-3.11.8/Programs/_freeze_module.py',
  'FROZEN_FILES_IN': '\\',
  'FROZEN_FILES_OUT': '\\',
  'GETPGRP_HAVE_ARG': 0,
@@ -350,6 +353,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 0,
+ 'HAVE_LINUX_LIMITS_H': 0,
  'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_QRTR_H': 0,
@@ -371,8 +375,8 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_MAKEDEV': 0,
  'HAVE_MBRTOWC': 1,
  'HAVE_MEMFD_CREATE': 0,
+ 'HAVE_MEMORY_H': 1,
  'HAVE_MEMRCHR': 0,
- 'HAVE_MINIX_CONFIG_H': 0,
  'HAVE_MKDIRAT': 0,
  'HAVE_MKFIFO': 0,
  'HAVE_MKFIFOAT': 0,
@@ -432,6 +436,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RENAMEAT': 0,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
@@ -501,7 +506,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_STAT_TV_NSEC2': 0,
  'HAVE_STDARG_PROTOTYPES': 1,
  'HAVE_STDINT_H': 1,
- 'HAVE_STDIO_H': 1,
  'HAVE_STDLIB_H': 1,
  'HAVE_STD_ATOMIC': 1,
  'HAVE_STRFTIME': 1,
@@ -651,9 +655,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-fvisibility=hidden -D_WIN32_WINNT=0x0602 '
                     '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                     '-DMS_DLL_ID=\'"3.11-32"\' -fprofile-use '
-                    '-fprofile-correction -I../Python-3.11.4/Include/internal '
+                    '-fprofile-correction -I../Python-3.11.8/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I../Python-3.11.4/Include -I../Python-3.11.4/PC '
+                    '-I../Python-3.11.8/Include -I../Python-3.11.8/PC '
                     '-D__USE_MINGW_ANSI_STDIO=1 -I. -D__USE_MINGW_ANSI_STDIO=1',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -670,9 +674,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-D_WIN32_WINNT=0x0602 '
                     '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                     '-DMS_DLL_ID=\'"3.11-32"\' -fprofile-use '
-                    '-fprofile-correction -I../Python-3.11.4/Include/internal '
+                    '-fprofile-correction -I../Python-3.11.8/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
-                    '-I../Python-3.11.4/Include -I../Python-3.11.4/PC '
+                    '-I../Python-3.11.8/Include -I../Python-3.11.8/PC '
                     '-D__USE_MINGW_ANSI_STDIO=1 -I. -D__USE_MINGW_ANSI_STDIO=1',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -705,7 +709,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '../Python-3.11.4/Modules/makesetup',
+ 'MAKESETUP': '../Python-3.11.8/Modules/makesetup',
  'MANDIR': '/mingw32/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  nt  _signal  _tracemalloc  _codecs  '
@@ -736,7 +740,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_BINASCII_CFLAGS': '-DUSE_ZLIB_CRC32',
  'MODULE_BINASCII_LDFLAGS': '-lz',
  'MODULE_BINASCII_STATE': 'yes',
- 'MODULE_CMATH_DEPS': '../Python-3.11.4/Modules/_math.h',
+ 'MODULE_CMATH_DEPS': '../Python-3.11.8/Modules/_math.h',
  'MODULE_CMATH_LDFLAGS': '-lm',
  'MODULE_CMATH_STATE': 'yes',
  'MODULE_ERRNO_LDFLAGS': '',
@@ -744,7 +748,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_FCNTL_STATE': 'missing',
  'MODULE_GRP_STATE': 'missing',
  'MODULE_ITERTOOLS_LDFLAGS': '',
- 'MODULE_MATH_DEPS': '../Python-3.11.4/Modules/_math.h',
+ 'MODULE_MATH_DEPS': '../Python-3.11.8/Modules/_math.h',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
@@ -765,8 +769,8 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_TERMIOS_STATE': 'missing',
  'MODULE_TIME_LDFLAGS': '',
  'MODULE_TIME_STATE': 'yes',
- 'MODULE_UNICODEDATA_DEPS': '../Python-3.11.4/Modules/unicodedata_db.h '
-                            '../Python-3.11.4/Modules/unicodename_db.h',
+ 'MODULE_UNICODEDATA_DEPS': '../Python-3.11.8/Modules/unicodedata_db.h '
+                            '../Python-3.11.8/Modules/unicodename_db.h',
  'MODULE_UNICODEDATA_STATE': 'yes',
  'MODULE_WINREG_LDFLAGS': '',
  'MODULE_WINSOUND_LDFLAGS': '-lwinmm',
@@ -781,22 +785,22 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ASYNCIO_STATE': 'yes',
  'MODULE__BISECT_STATE': 'yes',
  'MODULE__BLAKE2_CFLAGS': '',
- 'MODULE__BLAKE2_DEPS': '../Python-3.11.4/Modules/_blake2/impl/blake2-config.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2-impl.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2b-load-sse2.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2b-load-sse41.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2b-ref.c '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2b-round.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2b.c '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2s-load-sse2.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2s-load-sse41.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2s-load-xop.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2s-ref.c '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2s-round.h '
-                        '../Python-3.11.4/Modules/_blake2/impl/blake2s.c '
-                        '../Python-3.11.4/Modules/_blake2/blake2module.h '
-                        '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__BLAKE2_DEPS': '../Python-3.11.8/Modules/_blake2/impl/blake2-config.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2-impl.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-load-sse2.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-load-sse41.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-ref.c '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2b-round.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2b.c '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-load-sse2.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-load-sse41.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-load-xop.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-ref.c '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2s-round.h '
+                        '../Python-3.11.8/Modules/_blake2/impl/blake2s.c '
+                        '../Python-3.11.8/Modules/_blake2/blake2module.h '
+                        '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__BLAKE2_LDFLAGS': '',
  'MODULE__BLAKE2_STATE': 'yes',
  'MODULE__BZ2_CFLAGS': '',
@@ -813,27 +817,27 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CONTEXTVARS_STATE': 'yes',
  'MODULE__CRYPT_STATE': 'missing',
  'MODULE__CSV_STATE': 'yes',
- 'MODULE__CTYPES_DEPS': '../Python-3.11.4/Modules/_ctypes/ctypes.h',
+ 'MODULE__CTYPES_DEPS': '../Python-3.11.8/Modules/_ctypes/ctypes.h',
  'MODULE__CTYPES_TEST_LDFLAGS': '-lm',
  'MODULE__CTYPES_TEST_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
  'MODULE__DECIMAL_CFLAGS': '-DCONFIG_32=1 -DANSI=1',
- 'MODULE__DECIMAL_DEPS': '../Python-3.11.4/Modules/_decimal/docstrings.h',
+ 'MODULE__DECIMAL_DEPS': '../Python-3.11.8/Modules/_decimal/docstrings.h',
  'MODULE__DECIMAL_LDFLAGS': '-lmpdec',
  'MODULE__DECIMAL_STATE': 'yes',
  'MODULE__ELEMENTTREE_CFLAGS': '',
- 'MODULE__ELEMENTTREE_DEPS': '../Python-3.11.4/Modules/pyexpat.c',
+ 'MODULE__ELEMENTTREE_DEPS': '../Python-3.11.8/Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
  'MODULE__GDBM_STATE': 'missing',
  'MODULE__HASHLIB_CFLAGS': '',
- 'MODULE__HASHLIB_DEPS': '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__HASHLIB_DEPS': '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
  'MODULE__HASHLIB_STATE': 'yes',
  'MODULE__HEAPQ_STATE': 'yes',
- 'MODULE__IO_CFLAGS': '-I../Python-3.11.4/Modules/_io',
- 'MODULE__IO_DEPS': '../Python-3.11.4/Modules/_io/_iomodule.h',
+ 'MODULE__IO_CFLAGS': '-I../Python-3.11.8/Modules/_io',
+ 'MODULE__IO_DEPS': '../Python-3.11.8/Modules/_io/_iomodule.h',
  'MODULE__IO_LDFLAGS': '',
  'MODULE__IO_STATE': 'yes',
  'MODULE__JSON_STATE': 'yes',
@@ -842,12 +846,12 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__LZMA_CFLAGS': '',
  'MODULE__LZMA_LDFLAGS': '-llzma',
  'MODULE__LZMA_STATE': 'yes',
- 'MODULE__MD5_DEPS': '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__MD5_DEPS': '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__MD5_STATE': 'yes',
  'MODULE__MSI_LDFLAGS': '-lmsi -lcabinet -lrpcrt4',
  'MODULE__MSI_STATE': 'yes',
  'MODULE__MULTIBYTECODEC_STATE': 'yes',
- 'MODULE__MULTIPROCESSING_CFLAGS': '-I../Python-3.11.4/Modules/_multiprocessing',
+ 'MODULE__MULTIPROCESSING_CFLAGS': '-I../Python-3.11.8/Modules/_multiprocessing',
  'MODULE__MULTIPROCESSING_STATE': 'yes',
  'MODULE__OPCODE_STATE': 'yes',
  'MODULE__OPERATOR_LDFLAGS': '',
@@ -859,42 +863,42 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__QUEUE_STATE': 'yes',
  'MODULE__RANDOM_STATE': 'yes',
  'MODULE__SCPROXY_STATE': 'n/a',
- 'MODULE__SHA1_DEPS': '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__SHA1_DEPS': '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__SHA1_STATE': 'yes',
- 'MODULE__SHA256_DEPS': '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__SHA256_DEPS': '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__SHA256_STATE': 'yes',
- 'MODULE__SHA3_DEPS': '../Python-3.11.4/Modules/_sha3/sha3.c '
-                      '../Python-3.11.4/Modules/_sha3/sha3.h '
-                      '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__SHA3_DEPS': '../Python-3.11.8/Modules/_sha3/sha3.c '
+                      '../Python-3.11.8/Modules/_sha3/sha3.h '
+                      '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__SHA3_STATE': 'yes',
- 'MODULE__SHA512_DEPS': '../Python-3.11.4/Modules/hashlib.h',
+ 'MODULE__SHA512_DEPS': '../Python-3.11.8/Modules/hashlib.h',
  'MODULE__SHA512_STATE': 'yes',
- 'MODULE__SOCKET_DEPS': '../Python-3.11.4/Modules/socketmodule.h '
-                        '../Python-3.11.4/Modules/addrinfo.h '
-                        '../Python-3.11.4/Modules/getaddrinfo.c '
-                        '../Python-3.11.4/Modules/getnameinfo.c',
+ 'MODULE__SOCKET_DEPS': '../Python-3.11.8/Modules/socketmodule.h '
+                        '../Python-3.11.8/Modules/addrinfo.h '
+                        '../Python-3.11.8/Modules/getaddrinfo.c '
+                        '../Python-3.11.8/Modules/getnameinfo.c',
  'MODULE__SOCKET_LDFLAGS': '',
  'MODULE__SOCKET_STATE': 'yes',
- 'MODULE__SQLITE3_CFLAGS': '-I../Python-3.11.4/Modules/_sqlite',
- 'MODULE__SQLITE3_DEPS': '../Python-3.11.4/Modules/_sqlite/connection.h '
-                         '../Python-3.11.4/Modules/_sqlite/cursor.h '
-                         '../Python-3.11.4/Modules/_sqlite/microprotocols.h '
-                         '../Python-3.11.4/Modules/_sqlite/module.h '
-                         '../Python-3.11.4/Modules/_sqlite/prepare_protocol.h '
-                         '../Python-3.11.4/Modules/_sqlite/row.h '
-                         '../Python-3.11.4/Modules/_sqlite/util.h',
+ 'MODULE__SQLITE3_CFLAGS': '-I../Python-3.11.8/Modules/_sqlite',
+ 'MODULE__SQLITE3_DEPS': '../Python-3.11.8/Modules/_sqlite/connection.h '
+                         '../Python-3.11.8/Modules/_sqlite/cursor.h '
+                         '../Python-3.11.8/Modules/_sqlite/microprotocols.h '
+                         '../Python-3.11.8/Modules/_sqlite/module.h '
+                         '../Python-3.11.8/Modules/_sqlite/prepare_protocol.h '
+                         '../Python-3.11.8/Modules/_sqlite/row.h '
+                         '../Python-3.11.8/Modules/_sqlite/util.h',
  'MODULE__SQLITE3_LDFLAGS': '-lsqlite3',
  'MODULE__SQLITE3_STATE': 'yes',
  'MODULE__SRE_LDFLAGS': '',
  'MODULE__SSL_CFLAGS': '',
- 'MODULE__SSL_DEPS': '../Python-3.11.4/Modules/_ssl.h '
-                     '../Python-3.11.4/Modules/_ssl/cert.c '
-                     '../Python-3.11.4/Modules/_ssl/debughelpers.c '
-                     '../Python-3.11.4/Modules/_ssl/misc.c '
-                     '../Python-3.11.4/Modules/_ssl_data.h '
-                     '../Python-3.11.4/Modules/_ssl_data_111.h '
-                     '../Python-3.11.4/Modules/_ssl_data_300.h '
-                     '../Python-3.11.4/Modules/socketmodule.h',
+ 'MODULE__SSL_DEPS': '../Python-3.11.8/Modules/_ssl.h '
+                     '../Python-3.11.8/Modules/_ssl/cert.c '
+                     '../Python-3.11.8/Modules/_ssl/debughelpers.c '
+                     '../Python-3.11.8/Modules/_ssl/misc.c '
+                     '../Python-3.11.8/Modules/_ssl_data.h '
+                     '../Python-3.11.8/Modules/_ssl_data_111.h '
+                     '../Python-3.11.8/Modules/_ssl_data_300.h '
+                     '../Python-3.11.8/Modules/socketmodule.h',
  'MODULE__SSL_LDFLAGS': '-lssl -lcrypto -lws2_32',
  'MODULE__SSL_STATE': 'yes',
  'MODULE__STATISTICS_LDFLAGS': '-lm',
@@ -903,7 +907,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__STRUCT_STATE': 'yes',
  'MODULE__SYMTABLE_LDFLAGS': '',
  'MODULE__TESTBUFFER_STATE': 'yes',
- 'MODULE__TESTCAPI_DEPS': '../Python-3.11.4/Modules/testcapi_long.h',
+ 'MODULE__TESTCAPI_DEPS': '../Python-3.11.8/Modules/testcapi_long.h',
  'MODULE__TESTCAPI_STATE': 'yes',
  'MODULE__TESTCLINIC_STATE': 'yes',
  'MODULE__TESTIMPORTMULTIPLE_STATE': 'yes',
@@ -982,9 +986,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                              '-DMS_DLL_ID=\'"3.11-32"\' -fprofile-use '
                              '-fprofile-correction '
-                             '-I../Python-3.11.4/Include/internal -IObjects '
+                             '-I../Python-3.11.8/Include/internal -IObjects '
                              '-IInclude -IPython -I. '
-                             '-I../Python-3.11.4/Include -I../Python-3.11.4/PC '
+                             '-I../Python-3.11.8/Include -I../Python-3.11.8/PC '
                              '-D__USE_MINGW_ANSI_STDIO=1 -I. '
                              '-D__USE_MINGW_ANSI_STDIO=1 '
                              '-DPy_BUILD_CORE_BUILTIN',
@@ -997,7 +1001,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fvisibility=hidden -D_WIN32_WINNT=0x0602 '
                      '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                      '-DMS_DLL_ID=\'"3.11-32"\' -fprofile-use '
-                     '-fprofile-correction -I../Python-3.11.4/Include/internal',
+                     '-fprofile-correction -I../Python-3.11.8/Include/internal',
  'PY_COERCE_C_LOCALE': 0,
  'PY_CORE_CFLAGS': '-DNDEBUG -g -fwrapv -O3 -Wall -march=pentium4 '
                    '-mtune=generic -O2 -pipe -Wp,-D_FORTIFY_SOURCE=2 '
@@ -1008,17 +1012,17 @@ build_time_vars = {'ABIFLAGS': '',
                    '-fvisibility=hidden -D_WIN32_WINNT=0x0602 '
                    '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                    '-DMS_DLL_ID=\'"3.11-32"\' -fprofile-use '
-                   '-fprofile-correction -I../Python-3.11.4/Include/internal '
+                   '-fprofile-correction -I../Python-3.11.8/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I../Python-3.11.4/Include -I../Python-3.11.4/PC '
+                   '-I../Python-3.11.8/Include -I../Python-3.11.8/PC '
                    '-D__USE_MINGW_ANSI_STDIO=1 -I. -D__USE_MINGW_ANSI_STDIO=1 '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-pipe -Wl,--no-seh -Wl,--large-address-aware '
                     '-Wl,--large-address-aware -pipe -Wl,--no-seh '
                     '-Wl,--large-address-aware -Wl,--large-address-aware '
                     '-fno-semantic-interposition',
- 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.4/Include '
-                '-I../Python-3.11.4/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+ 'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. -I../Python-3.11.8/Include '
+                '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                 '-D__USE_MINGW_ANSI_STDIO=1',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
@@ -1044,18 +1048,19 @@ build_time_vars = {'ABIFLAGS': '',
                         '-DPY3_DLLNAME=\'L"libpython3.11.dll"\' '
                         '-DMS_DLL_ID=\'"3.11-32"\' -fprofile-use '
                         '-fprofile-correction '
-                        '-I../Python-3.11.4/Include/internal -IObjects '
-                        '-IInclude -IPython -I. -I../Python-3.11.4/Include '
-                        '-I../Python-3.11.4/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
+                        '-I../Python-3.11.8/Include/internal -IObjects '
+                        '-IInclude -IPython -I. -I../Python-3.11.8/Include '
+                        '-I../Python-3.11.8/PC -D__USE_MINGW_ANSI_STDIO=1 -I. '
                         '-D__USE_MINGW_ANSI_STDIO=1',
  'PY_SUPPORT_TIER': 0,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
  'Py_STATS': 0,
+ 'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'RCFLAGS': '-DFIELD3=4150 -O COFF --target=pe-i386',
+ 'RCFLAGS': '-DFIELD3=8150 -O COFF --target=pe-i386',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
@@ -1092,7 +1097,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_sre   Modules/_xxtestfuzz   Modules/cjkcodecs   '
             'Modules/expat   Objects   Parser   Programs   Python   '
             'Python/frozen_modules   Python/deepfreeze PC',
- 'SRC_GDB_HOOKS': '../Python-3.11.4/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '../Python-3.11.8/Tools/gdb/libpython.py',
  'STATIC_LIBPYTHON': 1,
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -1105,7 +1110,7 @@ build_time_vars = {'ABIFLAGS': '',
  'TESTPATH': '',
  'TESTPYTHON': './python.exe -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': './python.exe -E ../Python-3.11.4/Tools/scripts/run_tests.py',
+ 'TESTRUNNER': './python.exe -E ../Python-3.11.8/Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
  'TEST_MODULES': 'yes',
@@ -1116,15 +1121,15 @@ build_time_vars = {'ABIFLAGS': '',
  'TZPATH': '/mingw32/share/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
- 'UPDATE_FILE': '../Python-3.11.4/Tools/scripts/update_file.py',
+ 'UPDATE_FILE': '../Python-3.11.8/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
  'VENVLAUNCHERDIR': '/mingw32/lib/python3.11/venv/scripts/nt',
  'VERSION': '3.11',
- 'VPATH': '../Python-3.11.4',
+ 'VPATH': '../Python-3.11.8',
  'WASM_ASSETS_DIR': './mingw32',
  'WASM_STDLIB': './mingw32/lib/python3.11/os.py',
  'WHEEL_PKG_DIR': '',
- 'WINDOW_HAS_FLAGS': 1,
+ 'WINDOW_HAS_FLAGS': 0,
  'WINDRES': 'windres',
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -1140,14 +1145,14 @@ build_time_vars = {'ABIFLAGS': '',
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
  'abs_builddir': 'C:/M/B/src/build-MINGW32',
  'abs_builddir_b2h': 'C:/M/B/src/build-MINGW32',
- 'abs_srcdir': 'C:/M/B/src/Python-3.11.4',
- 'abs_srcdir_b2h': 'C:/M/B/src/Python-3.11.4',
+ 'abs_srcdir': 'C:/M/B/src/Python-3.11.8',
+ 'abs_srcdir_b2h': 'C:/M/B/src/Python-3.11.8',
  'datarootdir': '/mingw32/share',
  'exec_prefix': '/mingw32',
  'prefix': 'D:/a/msys64/mingw32',
  'prefix_b2h': 'D:/a/msys64/mingw32',
- 'srcdir': 'C:/M/B/src/Python-3.11.4',
- 'srcdir_b2h': 'C:/M/B/src/Python-3.11.4'}
+ 'srcdir': 'C:/M/B/src/Python-3.11.8',
+ 'srcdir_b2h': 'C:/M/B/src/Python-3.11.8'}
 
 
 keys_to_replace = [
@@ -1163,4 +1168,4 @@ prefix = build_time_vars['BINDIR'][:-4]
 
 for key in keys_to_replace:
     value = build_time_vars[key]
-    build_time_vars[key] = value.replace(prefix, sys.prefix)
+    build_time_vars[key] = value.replace(prefix, sys.base_prefix)
